@@ -2,13 +2,13 @@
 #'
 #' Creates a vector of integer study identifiers corresponding to the rows of a
 #' CompadreDB object, based on unique combinations of the columns 'Authors',
-#' 'Journal', 'YearPublication', and 'DOI.ISBN' (or optionally, a different set
+#' 'Journal', 'YearPublication', and 'DOI_ISBN' (or optionally, a different set
 #' of columns supplied by the user).
 #'
 #' @param cdb A CompadreDB object
 #' @param columns Vector of column names from which unique combinations should
 #'   be identified. Defaults to \code{c("Authors", "Journal", "YearPublication",
-#'   "DOI.ISBN")}.
+#'   "DOI_ISBN")}.
 #' 
 #' @return Vector of integer study identifiers corresponding to the rows of
 #'   \code{cdb}, based on unique combinations of the elements in \code{columns}.
@@ -29,7 +29,7 @@
 #' 
 #' @export cdb_id_studies
 cdb_id_studies <- function(cdb, columns = c("Authors", "Journal",
-                                            "YearPublication", "DOI.ISBN")) {
+                                            "YearPublication", "DOI_ISBN")) {
 
   cdb_id(cdb, columns)
 }
